==> foundation-2.7.1.tgz: package/Megaphone/Megaphone.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Megaphone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M27.328 28.507c-8.252 0-14.941 6.689-14.941 14.941s6.689 14.941 14.941 14.941a2.712 2.712 0 002.676-2.296h.043V31.227a2.72 2.72 0 00-2.719-2.72zm60.286-12.193a2.72 2.72 0 00-2.719-2.719c-.623 0-1.19.218-1.648.57L59.321 27.979H37.753a2.719 2.719 0 00-2.719 2.719v25.809h.034a2.71 2.71 0 002.685 2.383h19.138l26.16 15.103c.485.45 1.13.731 1.844.731a2.72 2.72 0 002.719-2.719c0-.103-.019-.201-.03-.301h.03V16.472h-.016c.003-.053.016-.103.016-.158zM56.212 79.572l-.038-.066c-.013-.024-.019-.049-.033-.073s-.032-.042-.046-.064L47.79 64.986l-.031.018a2.7 2.7 0 00-1.857-1.096v-.03H38.68v.018a2.693 2.693 0 00-1.135.347 2.718 2.718 0 00-.995 3.714c.064.11.142.206.219.303l-.032.019 9.678 16.764.002.005a.014.014 0 00.003.004l.097.168.017-.01a2.71 2.71 0 003.596.832c.145-.084.276-.183.399-.287l.025.043 4.983-2.876-.023-.04a2.708 2.708 0 00.691-3.306l.007-.004z"
  }));
});
Megaphone.displayName = 'Megaphone';
export var MegaphoneDimensions = {
  height: 100,
  width: 100
};

==> foundation-10.15.1.tgz: package/Megaphone/Megaphone.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var Megaphone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M27.328 28.507c-8.252 0-14.941 6.689-14.941 14.941s6.689 14.941 14.941 14.941a2.712 2.712 0 002.676-2.296h.043V31.227a2.72 2.72 0 00-2.719-2.72zm60.286-12.193a2.72 2.72 0 00-2.719-2.719c-.623 0-1.19.218-1.648.57L59.321 27.979H37.753a2.719 2.719 0 00-2.719 2.719v25.809h.034a2.71 2.71 0 002.685 2.383h19.138l26.16 15.103c.485.45 1.13.731 1.844.731a2.72 2.72 0 002.719-2.719c0-.103-.019-.201-.03-.301h.03V16.472h-.016c.003-.053.016-.103.016-.158zM56.212 79.572l-.038-.066c-.013-.024-.019-.049-.033-.073s-.032-.042-.046-.064L47.79 64.986l-.031.018a2.7 2.7 0 00-1.857-1.096v-.03H38.68v.018a2.693 2.693 0 00-1.135.347 2.718 2.718 0 00-.995 3.714c.064.11.142.206.219.303l-.032.019 9.678 16.764.002.005a.014.014 0 00.003.004l.097.168.017-.01a2.71 2.71 0 003.596.832c.145-.084.276-.183.399-.287l.025.043 4.983-2.876-.023-.04a2.708 2.708 0 00.691-3.306l.007-.004z"
  }));
});
Megaphone.displayName = 'Megaphone';
export var MegaphoneDimensions = {
  height: 100,
  width: 100
};
